@@ -6,6 +6,7 @@ Written by Lucas Sinclair.
 GNUv3 Licensed.
 Contact at www.sinclair.bio
 Created in May 2021.
+Last Updated in May 2022.
 """
 
 # Built-in modules #
@@ -24,6 +25,9 @@ from fasta               import FASTA
 from autopaths.file_path import FilePath
 from autopaths.dir_path  import DirectoryPath
 
+# Constants #
+all_db_choices = ('midori248', 'silvamod138', 'silvamod128', 'bold')
+
 ###############################################################################
 class Classify:
     """
@@ -32,9 +36,9 @@ class Classify:
     obtained from environmental sequencing.
 
     After creating a new instance of a `Classify` object, you can simply call
-    it to have it process your input data and generate the assignments output
-    file. Examples are included in the README.md file of this package or
-    directly on the github page at:
+    it to get your input data processed and the assignments output file
+    generated. Examples are included in the `README.md` file of this package
+    which can directly be seen on the GitHub page at:
 
     https://github.com/xapple/crest4/
     """
@@ -43,7 +47,7 @@ class Classify:
                  fasta,
                  search_algo = 'blast',
                  num_threads = 1,
-                 search_db   = 'silvamod138',
+                 search_db   = 'midori248',
                  output_dir  = None,
                  search_hits = None,
                  min_score   = None,
@@ -61,21 +65,22 @@ class Classify:
             search_algo: The algorithm used for the sequence similarity search
                          that will be run to match the sequences against the
                          database chosen. Either `blast` or `vsearch`. No
-                         other values are currently supported. By default
+                         other values are currently supported. By default,
                          `blast`.
 
             num_threads: The number of processors to use for the sequence
-                         similarity search. By default parallelism is turned
+                         similarity search. By default, parallelism is turned
                          off and this value is 1. If you pass the value `True`
                          we will run as many processes as there are CPUs but
                          no more than 32.
 
             search_db: The database used for the sequence similarity search.
-                       Either `silvamod138`, `silvamod128` or 'bold'. No other
-                       values are currently supported. By default `silvamod138`.
-                       Optionally the user can provide his own custom database
-                       by specifying the full path to a directory containing
-                       all required files under `search_db`. See README.
+                       Either `midori248`, `silvamod138`, or `bold`.
+                       No other values are currently supported.
+                       By default, `midori248`. Optionally, the user can
+                       provide a custom database by specifying the full path
+                       to a directory containing all required files under
+                       `search_db`. See the README for more information.
 
             output_dir: The directory into which all the classification
                         results will be written to. This defaults to a
@@ -85,7 +90,7 @@ class Classify:
             search_hits: The path where the search results will be stored.
                          This defaults to the output directory. However,
                          if the search operation has already been completed
-                         before hand, specify the path here to skip the
+                         beforehand, specify the path here to skip the
                          sequence similarity search step and go directly to
                          the taxonomy step. If a hits file exists in the output
                          directory and this option is not specified, it is
@@ -108,7 +113,7 @@ class Classify:
                         on or off. Pass any value like `False` to turn it off.
                         The minimum similarity filter prevents classification
                         to higher ranks when a minimum rank-identity is not met.
-                        By default `True`.
+                        The default is `True`.
 
             otu_table: Optionally, one can specify the path to an OTU table in
                        CSV or TSV format when running `crest4`. If this option
@@ -153,6 +158,8 @@ class Classify:
                 self.num_threads = 1
             elif self.num_threads.lower() == 'true':
                 self.num_threads = min(multiprocessing.cpu_count(), 32)
+        # The database is always a string #
+        self.search_db = str(self.search_db)
         # Default for the output directory #
         if self.output_dir is None:
             self.output_dir = self.fasta + '.crest4/'
@@ -201,7 +208,8 @@ class Classify:
             msg = "The search algorithm '%s' is not supported."
             raise ValueError(msg % self.search_algo)
         # Check the search database #
-        if self.search_db not in ('silvamod128', 'silvamod138', 'bold'):
+        if self.search_db not in all_db_choices and \
+          not os.path.exists(self.search_db):
             msg = "The search database '%s' is not supported."
             raise ValueError(msg % self.search_db)
         # Check the minimum score value is above zero #
@@ -230,10 +238,12 @@ class Classify:
     @property_cached
     def database(self):
         """Retrieve the database object that the user has selected."""
-        if '/' in self.search_db:
+        if self.search_db not in all_db_choices and \
+          os.path.exists(self.search_db):
             short_name = os.path.basename(os.path.dirname(self.search_db))
-            long_name  = "Custom user provided database '%s'." % short_name
-            return CrestDatabase(short_name, long_name, self.search_db)
+            long_name  = "Custom user-provided database '%s'." % short_name
+            return CrestDatabase(short_name, long_name,
+                                 self.search_db + '/../')
         else:
             return getattr(crest4.databases, self.search_db)
 
@@ -243,6 +253,7 @@ class Classify:
         """
         An object representing the sequence similarity search.
         Makes use of the `seqsearch` module. For reference:
+
         * Setting `-outfmt` to 5 means XML output.
         * Setting `-outfmt` to 6 means tabular output.
         * Setting `-outfmt` to 7 means tabular output with comments.
