@@ -12,7 +12,6 @@ Created in May 2021.
 import os, json
 
 # Internal modules #
-
 import crest4
 
 # First party modules #
@@ -30,14 +29,14 @@ class CrestMetadata:
     """
     The databases that `crest4` needs are slightly too large to be distributed
     with the source tarball on PyPI. Therefore, we host them on a separate
-    server. Currently this is S3 on AWS.
+    server. Currently, this is S3 on AWS.
 
     Over the course of years however these servers might be shutdown.
     To avoid this inconvenience, instead of hard-coding the server address here
     in the source file, we instead maintain a metadata file.
 
     This metadata file contains the up-to-date URLs of the databases
-    to download. It is placed in the github repository and only the location
+    to download. It is placed in the GitHub repository and only the location
     of the metadata file is hardcoded into the source code.
 
     This enables updating the URLs without having to issue a new release of
@@ -55,7 +54,7 @@ class CrestMetadata:
     # This will always retrieve the raw content of the latest version #
     metadata_url = base_url + repo_path
 
-    # To see the HTML version on github simply head to this address instead:
+    # To see the HTML version on GitHub simply head to this address instead:
     # https://github.com/xapple/crest4/blob/master/crest4/crest4_db_urls.json
 
     @property_cached
@@ -110,6 +109,8 @@ class CrestDatabase:
             base_dir = os.environ.get(self.environ_var, self.default_dir)
         # Convert to a DirectoryPath #
         self.base_dir = DirectoryPath(base_dir)
+        # And make it absolute #
+        self.base_dir = DirectoryPath(self.base_dir.absolute_path)
 
     def __repr__(self):
         """A simple representation of this object to avoid memory addresses."""
@@ -219,7 +220,7 @@ class CrestDatabase:
     @property_cached
     def tree(self):
         """
-        Using the `.tre` file, we return a N-ary tree in memory.
+        Using the `.tre` file, we return an N-ary tree in memory.
         Every node is characterised by a number. For instance between
         1 and 32477.
         """
@@ -262,12 +263,12 @@ class CrestDatabase:
         # Create a dictionary #
         with open(path, 'rt') as handle: return dict(parse_lines(handle))
 
-    #--------------------------- Extra information ----------------------------#
+    #--------------------------- Extra information ---------------------------#
     @property
     def rank_names(self):
-        return ['Root',           # 0
-                'Genome',         # 1 (This is for instance mitochondria)
-                'Domain',         # 2
+        return ['Root',           # 0 (This is life itself)
+                'Genome',         # 1 (This is for instance 'mitochondria')
+                'Domain',         # 2 (This is Bacteria, Archaea or Eucarya)
                 'Superkingdom',   # 3
                 'Kingdom',        # 4 (This is also called Superphylum)
                 'Phylum',         # 5
@@ -278,11 +279,14 @@ class CrestDatabase:
                 'Species',        # 10
                 'Strain',         # 11
                 'Strain',         # 12
-                'Strain',         # 13 (There is a problem with too many ranks in 
-                'Strain']         # 14 some databases requiring this)
+                'Strain',         # 13 (There is a problem with too many ranks
+                'Strain']         # 14  in some databases requiring this)
 
 ###############################################################################
 # As our databases should only be stored on disk once, so we have singletons #
+midori248   = CrestDatabase('midori248',
+                            'The midori248darn database for CREST')
+
 silvamod138 = CrestDatabase('silvamod138',
                             'Silva version 138 modified for CREST')
 
